@@ -60,8 +60,9 @@ def set_user_display(request, display, model, **model_kwargs):
             obj.delete()
     else:
         if not obj:
-            model.objects.create(user=request.user, display=display,
-                                 site_id=settings.SITE_ID, **model_kwargs)
+            obj = model(user=request.user, display=display, **model_kwargs)
+            obj.site_id = settings.SITE_ID
+            obj.save()
         elif obj.display != display:
             obj.display = display
             obj.save()
